pub enum Base64Variant {
Unpadded,
Padded,
}Expand description
Enum controlling how the high-entropy passphrase used to be created on the client side.
This allows us to replicate how a random key was converted into a passphrase to migrate from said passphrase to the plain key.
Variants
Unpadded
Unpadded base64 was used to create the high-entropy passphrase.
Padded
Standard padded base64 was used to create the high-entropy passphrase.