pub enum Synchronous {
Off,
Normal,
Full,
Extra,
}Expand description
How often SQLite syncs the database to the storage device.
See PRAGMA synchronous to learn more.
Variants
Off
SQLite never syncs. A crash of the operating system can corrupt the database.
Normal
SQLite syncs at the most critical moments. In WAL mode, that is one
fsync per checkpoint.
Full
SQLite syncs at every transaction. In WAL mode, that is one fsync of
the WAL file per commit. This is the default of SQLite.
Extra
Like Synchronous::Full, plus one fsync of the directory when a
rollback journal is deleted. This has no effect in WAL mode.